TelegramRobust2Steganography class

TelegramRobust2 DCT steganography (resize + JPEG Q80 + robust2 channel).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

embed(Uint8List imageBytes, Uint8List data) Uint8List
extract(Uint8List imageBytes) Uint8List?