JpegStegoNative class
FFI bindings to the desktop libjpegstego shared library.
Build with: bash tool/build_native.sh
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dctEmbed(
Uint8List jpegBytes, Uint8List payload) → Uint8List? -
dctExtract(
Uint8List jpegBytes, int maxBytes) → Uint8List? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
robust2Embed(
Uint8List jpegBytes, Uint8List payload) → Uint8List? -
robust2Extract(
Uint8List jpegBytes) → Uint8List? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → JpegStegoNative
-
no setter
- isAvailable → bool
-
no setter