LsbSteganography class

Pure-Dart LSB embed/extract (matches native LsbSteganography on Android/iOS).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

embedPng(Uint8List pngBytes, Uint8List data) Uint8List
extractPng(Uint8List pngBytes) Uint8List?