SteganographyCrypto class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decrypt(Uint8List packed, {required Uint8List keyBytes}) Future<Uint8List>
encrypt(Uint8List plaintext, {required Uint8List keyBytes, SteganographyCipher cipher = SteganographyCipher.aes256Gcm}) Future<Uint8List>