StegoPayload class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
pack(
Uint8List encryptedPackage) → Uint8List -
packDrm(
Uint8List encryptedPackage) → Uint8List -
packRobust(
Uint8List encryptedPackage, {required Uint8List keyBytes, int repetition = _defaultRepetition}) → Uint8List -
tryUnpack(
Uint8List embedded) → Uint8List? -
tryUnpackDrm(
Uint8List embedded) → Uint8List? -
tryUnpackRobust(
Uint8List embedded, {required Uint8List keyBytes}) → Uint8List?