MethodChannelSteganography class

Constructors

MethodChannelSteganography()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

embedPng({required Uint8List pngBytes, required Uint8List payload, required int method}) Future<Uint8List>
extractPng({required Uint8List pngBytes, required int method}) Future<Uint8List?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited