SteganographyEngine class
Constructors
- SteganographyEngine()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
embed(
{required Uint8List imageBytes, required Uint8List data, required Uint8List key, required SteganographyMethod method, SteganographyCipher cipher = SteganographyCipher.aes256Gcm}) → Future< Uint8List> -
extract(
{required Uint8List imageBytes, required Uint8List key, required SteganographyMethod method}) → Future< Uint8List> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited