SteganographyMethod enum
Steganography algorithm applied to the image carrier.
Values
- lsb → const SteganographyMethod
-
Least significant bits in RGB channels. High capacity, PNG/JPEG.
- dct → const SteganographyMethod
-
JPEG luma DCT coefficients, 1 bit per 8×8 block. Uses STG2 robust pack.
- telegramRobust2 → const SteganographyMethod
-
Robust DCT with pseudo-random block order for lossy channels (STG2).
- dctResidualModulation → const SteganographyMethod
-
Residual modulation for heavy social-network recompression (STG4).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SteganographyMethod> - A constant List of the values in this enum, in order of their declaration.